From 47f8def355bb98ecc4485a31c9f6246d174a5d21 Mon Sep 17 00:00:00 2001
From: "Jason A. Donenfeld" <Jason@zx2c4.com>
Date: Wed, 3 Apr 2013 19:10:26 +0200
Subject: [PATCH] Add find command.

The find command will search for password items in the password store that
match provided arguments.

For example, `pass search mail bank` will show all the password items
in the password store that match `mail` or `bank`.

Directories are not matched, but they should be before this is committed.
---
 man/pass.1            | 21 +++++++++++++++++++++
 src/password-store.sh | 15 +++++++++++++--
 2 files changed, 34 insertions(+), 2 deletions(-)

diff --git a/man/pass.1 b/man/pass.1
index efb5d9b..c30234f 100644
--- a/man/pass.1
+++ b/man/pass.1
@@ -68,6 +68,12 @@ by using the
 .BR tree (1)
 program. This command is alternatively named \fBlist\fP.
 .TP
+\fBfind\fP \fIsearch-term\fP...
+List names of passwords inside the tree that match \fIsearch-term\fP(s) by using
+the
+.BR tree (1)
+program.
+.TP
 \fBshow\fP [ \fI--clip\fP, \fI-c\fP ] \fIpass-name\fP
 Decrypt and print a password named \fIpass-name\fP. If \fI--clip\fP or \fI-c\fP
 is specified, do not print the password but instead copy the first line to the
@@ -161,6 +167,21 @@ Password Store
 .br
 Alternatively, "\fBpass ls\fP".
 .TP
+Find existing passwords in store that match .com
+.B zx2c4@laptop ~ $ pass find .com
+.br
+Terms: .com
+.br
+\[u251C]\[u2500]\[u2500] Business 
+.br
+\[u2502]   \[u251C]\[u2500]\[u2500] some-silly-business-site.com 
+.br
+\[u2514]\[u2500]\[u2500] Email 
+.br
+    \[u251C]\[u2500]\[u2500] donenfeld.com 
+.br
+    \[u2514]\[u2500]\[u2500] zx2c4.com 
+.TP
 Show existing password
 .B zx2c4@laptop ~ $ pass Email/zx2c4.com 
 .br
diff --git a/src/password-store.sh b/src/password-store.sh
index 99010e9..d72717c 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright (C) 2012 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
+# Copyright (C) 2012-2013 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
 # This file is licensed under the GPLv2+. Please see COPYING for more information.
 
 umask 077
@@ -38,6 +38,8 @@ Usage:
     $program [show] [--clip,-c] pass-name
         Show existing password and optionally put it on the clipboard.
         If put on the clipboard, it will be cleared in 45 seconds.
+    $program find search-term...
+        List passwords and directories that match search-term(s).
     $program insert [--echo,-e | --multiline,-m] [--force,-f] pass-name
         Insert new password. Optionally, the console can be enabled echo
         the password back. Or, optionally, it may be multiline. Prompt
@@ -63,7 +65,7 @@ _EOF
 }
 is_command() {
 	case "$1" in
-		init|ls|list|show|insert|edit|generate|remove|rm|delete|git|help|--help|version|--version) return 0 ;;
+		init|ls|list|find|show|insert|edit|generate|remove|rm|delete|git|help|--help|version|--version) return 0 ;;
 		*) return 1 ;;
 	esac
 }
@@ -229,6 +231,15 @@ case "$command" in
 			fi
 		fi
 		;;
+	find)
+		if [[ -z "$@" ]]; then
+			echo "Usage: $program $command search-term..."
+			exit 1
+		fi
+		pattern="$@"
+		echo "Terms: $pattern"
+		tree -l --noreport -P "*${pattern// /*|*}*" --prune "$PREFIX/$path" | tail -n +2 | sed 's/\(.*\)\.gpg$/\1/'
+		;;
 	insert)
 		multiline=0
 		noecho=1
-- 
1.8.1.5

